summaryrefslogtreecommitdiff
path: root/libs/ardour/smf_source.cc
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2017-09-18 12:39:17 -0400
committerPaul Davis <paul@linuxaudiosystems.com>2017-09-18 12:39:17 -0400
commit30b087ab3d28f1585987fa3f6ae006562ae192e3 (patch)
tree620ae0250b5d77f90a18f8c2b83be61e4fe7b0b5 /libs/ardour/smf_source.cc
parentcb956e3e480716a3efd280a5287bdd7bee1cedc5 (diff)
globally change all use of "frame" to refer to audio into "sample".
Generated by tools/f2s. Some hand-editing will be required in a few places to fix up comments related to timecode and video in order to keep the legible
Diffstat (limited to 'libs/ardour/smf_source.cc')
-rw-r--r--libs/ardour/smf_source.cc76
1 files changed, 38 insertions, 38 deletions
diff --git a/libs/ardour/smf_source.cc b/libs/ardour/smf_source.cc
index 76d379e947..d622c33978 100644
--- a/libs/ardour/smf_source.cc
+++ b/libs/ardour/smf_source.cc
@@ -62,7 +62,7 @@ SMFSource::SMFSource (Session& s, const string& path, Source::Flag flags)
, Evoral::SMF()
, _open (false)
, _last_ev_time_beats(0.0)
- , _last_ev_time_frames(0)
+ , _last_ev_time_samples(0)
, _smf_last_read_end (0)
, _smf_last_read_time (0)
{
@@ -98,7 +98,7 @@ SMFSource::SMFSource (Session& s, const string& path)
, Evoral::SMF()
, _open (false)
, _last_ev_time_beats(0.0)
- , _last_ev_time_frames(0)
+ , _last_ev_time_samples(0)
, _smf_last_read_end (0)
, _smf_last_read_time (0)
{
@@ -130,7 +130,7 @@ SMFSource::SMFSource (Session& s, const XMLNode& node, bool must_exist)
, FileSource(s, node, must_exist)
, _open (false)
, _last_ev_time_beats(0.0)
- , _last_ev_time_frames(0)
+ , _last_ev_time_samples(0)
, _smf_last_read_end (0)
, _smf_last_read_time (0)
{
@@ -208,14 +208,14 @@ SMFSource::close ()
/* nothing to do: file descriptor is never kept open */
}
-/** All stamps in audio frames */
-framecnt_t
+/** All stamps in audio samples */
+samplecnt_t
SMFSource::read_unlocked (const Lock& lock,
- Evoral::EventSink<framepos_t>& destination,
- framepos_t const source_start,
- framepos_t start,
- framecnt_t duration,
- Evoral::Range<framepos_t>* loop_range,
+ Evoral::EventSink<samplepos_t>& destination,
+ samplepos_t const source_start,
+ samplepos_t start,
+ samplecnt_t duration,
+ Evoral::Range<samplepos_t>* loop_range,
MidiStateTracker* tracker,
MidiChannelFilter* filter) const
{
@@ -236,7 +236,7 @@ SMFSource::read_unlocked (const Lock& lock,
size_t scratch_size = 0; // keep track of scratch to minimize reallocs
- BeatsFramesConverter converter(_session.tempo_map(), source_start);
+ BeatsSamplesConverter converter(_session.tempo_map(), source_start);
const uint64_t start_ticks = converter.from(start).to_ticks();
DEBUG_TRACE (DEBUG::MidiSourceIO, string_compose ("SMF read_unlocked: start in ticks %1\n", start_ticks));
@@ -281,18 +281,18 @@ SMFSource::read_unlocked (const Lock& lock,
assert(time >= start_ticks);
- /* Note that we add on the source start time (in session frames) here so that ev_frame_time
- is in session frames.
+ /* Note that we add on the source start time (in session samples) here so that ev_sample_time
+ is in session samples.
*/
- const framepos_t ev_frame_time = converter.to(Evoral::Beats::ticks_at_rate(time, ppqn())) + source_start;
+ const samplepos_t ev_sample_time = converter.to(Evoral::Beats::ticks_at_rate(time, ppqn())) + source_start;
if (loop_range) {
- loop_range->squish (ev_frame_time);
+ loop_range->squish (ev_sample_time);
}
- if (ev_frame_time < start + duration) {
+ if (ev_sample_time < start + duration) {
if (!filter || !filter->filter(ev_buffer, ev_size)) {
- destination.write (ev_frame_time, Evoral::MIDI_EVENT, ev_size, ev_buffer);
+ destination.write (ev_sample_time, Evoral::MIDI_EVENT, ev_size, ev_buffer);
if (tracker) {
tracker->track(ev_buffer);
}
@@ -310,17 +310,17 @@ SMFSource::read_unlocked (const Lock& lock,
return duration;
}
-framecnt_t
+samplecnt_t
SMFSource::write_unlocked (const Lock& lock,
- MidiRingBuffer<framepos_t>& source,
- framepos_t position,
- framecnt_t cnt)
+ MidiRingBuffer<samplepos_t>& source,
+ samplepos_t position,
+ samplecnt_t cnt)
{
if (!_writing) {
mark_streaming_write_started (lock);
}
- framepos_t time;
+ samplepos_t time;
Evoral::EventType type;
uint32_t size;
@@ -331,16 +331,16 @@ SMFSource::write_unlocked (const Lock& lock,
_model->start_write();
}
- Evoral::Event<framepos_t> ev;
+ Evoral::Event<samplepos_t> ev;
while (true) {
/* Get the event time, in frames since session start but ignoring looping. */
bool ret;
if (!(ret = source.peek ((uint8_t*)&time, sizeof (time)))) {
/* Ring is empty, no more events. */
break;
}
- if ((cnt != max_framecnt) &&
+ if ((cnt != max_samplecnt) &&
(time > position + _capture_length + cnt)) {
/* The diskstream doesn't want us to write everything, and this
event is past the end of this block, so we're done for now. */
@@ -381,7 +381,7 @@ SMFSource::write_unlocked (const Lock& lock,
continue;
}
- append_event_frames(lock, ev, position);
+ append_event_samples(lock, ev, position);
}
Evoral::SMF::flush ();
@@ -445,28 +445,28 @@ SMFSource::append_event_beats (const Glib::Threads::Mutex::Lock& lock,
_flags = Source::Flag (_flags & ~Empty);
}
/** Append an event with a timestamp in frames (framepos_t) */
void
-SMFSource::append_event_frames (const Glib::Threads::Mutex::Lock& lock,
- const Evoral::Event<framepos_t>& ev,
- framepos_t position)
+SMFSource::append_event_samples (const Glib::Threads::Mutex::Lock& lock,
+ const Evoral::Event<samplepos_t>& ev,
+ samplepos_t position)
{
if (!_writing || ev.size() == 0) {
return;
}
// printf("SMFSource: %s - append_event_frames ID = %d time = %u, size = %u, data = ",
// name().c_str(), ev.id(), ev.time(), ev.size());
// for (size_t i=0; i < ev.size(); ++i) printf("%X ", ev.buffer()[i]); printf("\n");
- if (ev.time() < _last_ev_time_frames) {
- warning << string_compose(_("Skipping event with unordered frame time %1 < %2"),
- ev.time(), _last_ev_time_frames)
+ if (ev.time() < _last_ev_time_samples) {
+ warning << string_compose(_("Skipping event with unordered sample time %1 < %2"),
+ ev.time(), _last_ev_time_samples)
<< endmsg;
return;
}
- BeatsFramesConverter converter(_session.tempo_map(), position);
+ BeatsSamplesConverter converter(_session.tempo_map(), position);
const Evoral::Beats ev_time_beats = converter.from(ev.time());
Evoral::event_id_t event_id;
@@ -486,12 +486,12 @@ SMFSource::append_event_frames (const Glib::Threads::Mutex::Lock& lock,
_length_beats = max(_length_beats, ev_time_beats);
- const Evoral::Beats last_time_beats = converter.from (_last_ev_time_frames);
+ const Evoral::Beats last_time_beats = converter.from (_last_ev_time_samples);
const Evoral::Beats delta_time_beats = ev_time_beats - last_time_beats;
const uint32_t delta_time_ticks = delta_time_beats.to_ticks(ppqn());
Evoral::SMF::append_event_delta(delta_time_ticks, ev.size(), ev.buffer(), event_id);
- _last_ev_time_frames = ev.time();
+ _last_ev_time_samples = ev.time();
_flags = Source::Flag (_flags & ~Empty);
}
@@ -533,7 +533,7 @@ SMFSource::mark_streaming_midi_write_started (const Lock& lock, NoteMode mode)
MidiSource::mark_streaming_midi_write_started (lock, mode);
Evoral::SMF::begin_write ();
_last_ev_time_beats = Evoral::Beats();
- _last_ev_time_frames = 0;
+ _last_ev_time_samples = 0;
}
void
@@ -331,16 +331,16 @@ SMFSource::write_unlocked (const Lock& lock,
while (true) {
- /* Get the event time, in frames since session start but ignoring looping. */
+ /* Get the event time, in samples since session start but ignoring looping. */
bool ret;
if (!(ret = source.peek ((uint8_t*)&time, sizeof (time)))) {
@@ -445,28 +445,28 @@ SMFSource::append_event_beats (const Glib::Threads::Mutex::Lock& lock,
_flags = Source::Flag (_flags & ~Empty);
}
-/** Append an event with a timestamp in frames (framepos_t) */
+/** Append an event with a timestamp in samples (samplepos_t) */
void
@@ -445,28 +445,28 @@ SMFSource::append_event_beats (const Glib::Threads::Mutex::Lock& lock,
return;
}
- // printf("SMFSource: %s - append_event_frames ID = %d time = %u, size = %u, data = ",
+ // printf("SMFSource: %s - append_event_samples ID = %d time = %u, size = %u, data = ",
// name().c_str(), ev.id(), ev.time(), ev.size());
// for (size_t i=0; i < ev.size(); ++i) printf("%X ", ev.buffer()[i]); printf("\n");